@@ -160,10 +160,10 @@ class WorkflowEngine:
                 with open(filepath, "rb") as binary_file:
                     # Read the whole file at once
                     content = binary_file.read()
-                str_content = content.decode("utf-8", errors='ignore')
+                str_content = content.decode("ascii", errors='ignore')
                 str_content = "".join([x for x in str_content if x != '' and x != '']).strip().strip('\x00')
-                # remain =math.ceil((len(str_content)/4) - int(len(str_content)/4))
-                # str_content = str_content[0:len(str_content)-remain]
+                remain =math.ceil((len(str_content)/4) - int(len(str_content)/4))
+                str_content = str_content[0:len(str_content)-remain]
                 idx = 0
                 if str_content.__contains__("fV0"):
                     str_content = str_content.split("fV0")[0][1:] + "fV0==="
@@ -172,15 +172,7 @@ class WorkflowEngine:
                         idx = str_content.index("In1d") + 4
                 if idx > 0:
                     str_content = str_content[0:idx]
-                decoded = base64.b64decode(str_content).decode("utf-8", errors='ignore')
-                t = 1
-                ## fV0=}]  of In1d = "}]
-                eq = "="
-
-                # idx = decoded.index("/*-  Zk
-                #  }]")
-                # if idx > 0:
-                #     decoded = decoded[0:idx+2]
+                decoded = base64.b64decode(str_content).decode("ascii", errors='ignore')
                 dict_list = json.loads(decoded)
                 return dict_list
             else:
@@ -893,6 +885,7 @@ class WorkflowEngine:
         if output_previous_step is not None:
             return output_previous_step
 
+
     def set_error(self, ex: any):
         """
         Set the internal error coming from the try-except
@@ -1675,9 +1668,3 @@ class Visio:
             setattr(retn, k, v)
         return retn
 
-
-# Test
-# engine = WorkflowEngine()
-# doc = engine.open(fr"C:\Users\joost\Documents\test3.flw")  # c:\\temp\\test.xml
-# steps = engine.get_flow(doc)
-# engine.run_flow(steps)
